const { dom, roles } = require("aria-query");
const {
  defineTemplateBodyVisitor,
  getAttributeValue,
  getElementType,
  isAttribute,
  makeDocsURL
} = require("../utils");

module.exports = {
  meta: {
    docs: {
      url: makeDocsURL("aria-role")
    },
    messages: {
      default:
        "Elements with ARIA roles must use a valid, non-abstract ARIA role."
    },
    schema: [
      {
        type: "object",
        properties: {
          ignoreNonDOM: {
            type: "boolean"
          }
        },
        additionalProperties: false
      }
    ]
  },
  create(context) {
    return defineTemplateBodyVisitor(context, {
      VAttribute(node) {
        const { ignoreNonDOM } = context.options[0] || {};
        if (ignoreNonDOM && !dom.has(getElementType(node.parent.parent))) {
          return;
        }

        if (!isAttribute(node, "role")) {
          return;
        }

        const value = getAttributeValue(node);
        if (typeof value !== "string") {
          return;
        }

        const valid = value
          .toLowerCase()
          .split(" ")
          .every((role) => roles.has(role) && !roles.get(role).abstract);

        if (!valid) {
          context.report({ node, messageId: "default" });
        }
      }
    });
  }
};
